# sympyhelpers

Helper routines and definitions for sympy.  In particular, these methods wrap existing `sympy` functionality to do Newton-Euler and Lagrangian mechanics using Kane-style and Newton notation and format the outputs to match (some of) the conventions used in various textbooks including Kasdin & Paley (2011).

[![Documentation Status](https://readthedocs.org/projects/sympyhelpers/badge/?version=latest)](https://sympyhelpers.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/sympyhelpers.svg)](https://badge.fury.io/py/sympyhelpers)



## Installation 

`sympyhelpers` is pip installable.  Just run:

```
pip install sympyhelpers
```

## Documentation
Click on the 'docs' badge, above, or navigate to: https://sympyhelpers.readthedocs.io/
